Listener

Struct Listener 

pub struct Listener { /* private fields */ }
The Listener struct holds a thread that listens for a specified string written to the console.

The Listener struct implements functions to check whether the string was typed, heard_key, and to wait for the string to get typed, wait_for_key. Create a new instance of Listener using new or new_case_insensitive and specify the string to listen for.

Implementations

Source

impl Listener

pub fn new(key: &str) -> Listener

Creates a new Listener instance.

The key is the string that the Listener listens for.

Panics

The new function panics if the key is an empty string

Examples
let listener = Listener::new("q");
pub fn new_case_insensitive(key: &str) -> Listener

Creates a new case insensitive Listener instance.

The key is the string that the Listener listens for.

Panics

The new_case_insensitive function panics if the key is an empty string

Examples
let listener = Listener::new_case_insensitive("q");
pub fn heard_key(&self) -> bool

Returns true if the Listener has heard the key.

Examples
let listener = Listener::new("q");
 
while !listener.heard_key() {
    println!("Waiting for key.");
}
pub fn wait_for_key(self) -> Result<bool, Box<dyn Any + Send>>

Blocks the current thread until the listening thread ends. This consumes the Listener.

Returns Ok containing a boolean indicating whether the key was heard.

Errors

Returns Err if the listening thread panicked.

Examples
let listener = Listener::new("q");
 
heard_key = listener.wait_for_key().unwrap();
 
assert!(heard_key);